use strict;
use warnings;

use Dummy;    # does not exist anywhere

exit;

__END__

=encoding utf-8

=head1 NAME

it's a dummy POD for testing

=head1 SYNOPSIS

Via the command-line program L<findeps>;

    require Nothing;
    use Nothing;
    use parent Nothing;

=head1 DESCRIPTION

Nothing to explain.

=head1 LICENSE

Copyright (C) worthmine.

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=head1 AUTHOR

Yuki Yoshida(L<worthmine|https://github.com/worthmine>)

=cut
